from enum import Enum


class TicktickIdKeys(Enum):
    HABIT_LIST = "HABIT_LIST"
    FOLDER_IDS = "FOLDER_IDS"
    VALID_LIST_IDS = "VALID_LIST_IDS"
    COLUMN_TAGS = "COLUMN_TAGS"
    PROJECTS_FOLDER_KEY = "projects_folder"
